discord_interactions library
Classes
- Activity
- Activity structure
- ActivityAssets
- Activity Assets structure
- ActivityButton
- Activity Button structure
- ActivityParty
- Activity Party structure
- ActivitySecrets
- Activity Secrets structure
- ActivityTimestamps
- Activity Timestamps structure
- AllowedMentions
- Allowed Mentions structure
- Application
- Application structure
- ApplicationCommand
- Application Command structure
- ApplicationCommandInteractionDataOption
- Application Command Interaction Data Option structure
- ApplicationCommandOption
- Application Command Option structure
- ApplicationCommandOptionChoice
- Application Command Option Choice structure
- ApplicationCommandPermissions
- Application Command Permissions structure
- Attachment
- Attachment structure
- AuditLog
- Audit Log structure
- AuditLogChange
- Audit Log Change structure
- AuditLogEntry
- Audit Log Entry structure
- Ban
- Ban structure
- Channel
- Channel structure
- ChannelMention
- Channel mention structure
- ClientStatus
- Client Status structure
- Component
- Component structure
- DiscordApi
- Base class for accessing the Discord API
- DiscordCdn
- Discord uses ids and hashes to render images in the client. These hashes can be retrieved through various API requests, like Get User. Below are the formats, size limitations, and CDN endpoints for images in Discord. The returned format can be changed by changing the extension name at the end of the URL. The returned size can be changed by appending a querystring of ?size=desired_size to the URL. Image size can be any power of two between 16 and 4096.
- DiscordColor
- All colors from the nyxx DiscordColor class
- DiscordHeader
- Convenience class that holds Discord API headers
- DiscordUserAgent
- Clients using the HTTP API must provide a valid User Agent which specifies information about the client library and version
- Embed
- Embed structure
- EmbedAuthor
- Embed Author structure
- EmbedField
- Embed Field structure
- Embed Footer structure
- EmbedImage
- Embed Image structure
- EmbedProvider
- Embed Provider structure
- EmbedThumbnail
- Embed Thumbnail structure
- EmbedVideo
- Embed Video structure
- Emoji
- Emoji structure
- EmojiEncoder
- Encodes emoji to be used in urls
- FollowedChannel
- Followed Channel structure
- Guild
- Guild structure
- GuildApplicationCommandPermissions
- Guild Application Command Permissions structure
- GuildMember
- Guild Member structure
- GuildPreview
- Guild Preview structure
- GuildScheduledEvent
- Guild Scheduled Event structure
- GuildScheduledEventEntityMetadata
- Guild Scheduled Event Entity Metadata structure
- GuildScheduledEventUser
- Guild Scheduled Event User structure
- GuildTemplate
- Guild Template structure
- GuildWidget
- Guild Widget structure
- ImageData
- Image data is a Data URI scheme that supports JPG, GIF, and PNG formats
- Integration
- Integration structure
- IntegrationAccount
- Integration Account structure
- IntegrationApplication
- Integration Application structure
- Interaction
- Inteaction structure
- InteractionCallbackData
- Interaction Callback Data structure
- InteractionData
- Interaction Data structure
- InteractionResponse
- Interaction Response structure
- InteractionValidator
- Validate received Interactions
- InvalidResponse
- An invalid ValidatedResponse
- Invite
- Invite structure
- InviteStageInstance
- Invite Stage Instance structure
- ListThreadsResponse
- List Threads Response structure
- Message
- Message structure
- MessageActivity
- Message Activity structure
- MessageFormatting
- Discord utilizes a subset of markdown for rendering message content on its clients, while also adding some custom functionality to enable things like mentioning users and channels.
- MessageInteraction
- Message Interaction structure
- MessageReference
- Message Reference structure
- ModifyGuildChannelPositionsParams
- Modify Guild Channel Positions params
- ModifyGuildRolePositionsParams
- Modify Guild Role Positions params
- OptionalAuditEntryInfo
- Optional Audit Entry Info structure
- PermissionOverwrite
- Overwrite structure
- PresenceUpdateEvent
- Presence Update Event fields
- Reaction
- Reaction structure
- ResolvedData
- Resolved Data structure
- Role
- Role structure
- RoleTags
- Role Tags structure
- SelectOption
- Select Option structure
- Snowflake
- Discord utilizes Twitter's snowflake format for uniquely identifiable descriptors (IDs). These IDs are guaranteed to be unique across all of Discord, except in some unique scenarios in which child objects share their parent's ID. Because Snowflake IDs are up to 64 bits in size (e.g. a uint64), they are always returned as strings in the HTTP API to prevent integer overflows in some languages. See Gateway ETF/JSON for more information regarding Gateway encoding.
- StageInstance
- Stage Instance structure
- Sticker
- Sticker structure
- StickerPack
- Sticker Pack structure
- Team
- Team object
- TeamMember
- Team Member object
- ThreadMember
- Thread Member structure
- ThreadMetadata
- Thread Metadata structure
- User
- User structure
-
ValidResponse<
U, T> - A valid ValidatedResponse
- VoiceRegion
- Voice Region structure
- VoiceState
- Voice State structure
- Webhook
- Webhook structure
- WelcomeScreen
- Welcome Screen structure
- WelcomeScreenChannel
- Welcome Screen Channel structure
Enums
- ActivityFlag
- Activity flags
- ActivityType
- Activity types
- AllowedMentionType
- Allowed Mention types
- ApplicationCommandOptionType
- Application Command Option types
- ApplicationCommandPermissionType
- Application Command Permission types
- ApplicationCommandType
- Application Command types
- ApplicationFlag
- Application flags
- AuditLogChangeKey
- Audit Log Change keys
- AuditLogEvent
- Audit Log events
- ButtonStyle
- Button Styles
- ChannelType
- Channel types
- ComponentType
- Component types
- DefaultMessageNotificationLevel
- Default Message Notification levels
- EmbedType
- Embed types
- ExplicitContentFilterLevel
- Explicit Content Filter levels
- GuildFeature
- Guild features
- GuildNsfwLevel
- Guild Nsfw levels
- GuildScheduledEventEntityType
- Guild Scheduled Event Entity types
- GuildScheduledEventStatus
- Guild Scheduled Event Status
- GuildWidgetStyle
- Widget Style options
- ImageFormat
- Image formats
- IntegrationExpireBehavior
- Integration Expire behaviors
- IntegrationType
- Integration types
- InteractionCallbackType
- Interaction Callback types
- InteractionType
- Interaction types
- InviteTargetType
- Invite Target types
- MembershipState
- Membership State enum
- MessageActivityType
- Message Activity types
- MessageFlag
- Message flags
- MessageType
- Message types
- MfaLevel
- Mfa levels
- Permission
- Bitwise Permission Flags
- PermissionOverwriteType
- Overwrite type
- PremiumTier
- Premium tiers
- PremiumType
- Premium types
- PresenceStatus
- Presence statuses
- PrivacyLevel
- Privacy Levels for guild scheduled events, stage instances, etc.
- StickerFormatType
- Sticker Format types
- StickerType
- Sticker types
- SystemChannelFlag
- System Channel flags
- ThreadAutoArchiveDuration
- Thread Auto Archive druations
- TimestampStyle
- Timestamps will display the given timestamp in the user's timezone and locale
- UserFlag
- User flags
- VerificationLevel
- Verification levels
- VideoQualityMode
- Video quality modes
- WebhookType
- Webhook types
Extensions
- ActivityFlagExtension on ActivityFlag
- Extension to convert flags to values
- ApplicationCommandTypeExtension on ApplicationCommandType
- Extension on ApplicationCommandType
- ApplicationFlagExtension on ApplicationFlag
- Extension to convert flags to values
- AuditLogChangeKeyExtension on AuditLogChangeKey
- Extension on AuditLogChangeKey
- AuditLogEventExtension on AuditLogEvent
- Extension on AuditLogEvent
- ChannelTypeExtension on ChannelType
- Extension on ChannelType
- DefaultMessageNotificationLevelExtension on DefaultMessageNotificationLevel
- Extension on DefaultMessageNotificationLevel
-
DioResponseValidator
on Future<
Response< U> > -
Extension on
DioResponsefutures for validation - ExplicitContentFilterLevelExtension on ExplicitContentFilterLevel
- Extension on ExplicitContentFilterLevel
- GuildScheduledEventEntityTypeExtension on GuildScheduledEventEntityType
- Extension on GuildScheduledEventEntityType
- GuildScheduledEventStatusExtension on GuildScheduledEventStatus
- Extension on GuildScheduledEventStatus
- GuildWidgetStyleExtension on GuildWidgetStyle
- Extension on GuildWidgetStyle
- ImageFormatExtension on ImageFormat
- Methods to get information about image formats
- InviteTargetTypeExtension on InviteTargetType
- Extension on InviteTargetType
- MessageFlagExtension on MessageFlag
- Extension to convert flags to values
- PermissionExtension on Permission
- Extension to convert flags to values
- PrivacyLevelExtension on PrivacyLevel
- Extension on PrivacyLevel
- StickerFormatTypeExtension on StickerFormatType
- Extension on StickerFormatType
- SystemChannelFlagExtension on SystemChannelFlag
- Extension to convert flags to values
- ThreadAutoArchiveDurationExtension on ThreadAutoArchiveDuration
- Extension on ThreadAutoArchiveDuration
- UserFlagExtension on UserFlag
- Extension to convert flags to values
-
ValidatedResponseTransformer
on Future<
ValidatedResponse< U> > - Extension on ValidatedResponse for transforming the response data
- VerificationLevelExtension on VerificationLevel
- Extension on VerificationLevel
- VideoQualityModeExtension on VideoQualityMode
- Extension on VideoQualityMode
Typedefs
-
TransformedResponse<
U, T> = (ValidResponse< U, T> ?, InvalidResponse?) - A transformed ValidatedResponse
-
ValidatedResponse<
U> = TransformedResponse< U, U> - A validated response